Converter

Trait Converter 

pub trait Converter<A> {
    // Required methods
    fn get_style(&self, annotation: &A) -> Option<Style>;
    fn get_link<'a>(&self, annotation: &'a A) -> Option<&'a str>;
}
A converter for HTML annotations.

This trait extracts the text formatting and links from the annotations created by a TextDecorator.

Required Methods

fn get_style(&self, annotation: &A) -> Option<Style>

Returns the style for the given annotation (if any).

Returns the link target for the given annotation (if any).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors